@@ -4,13 +4,8 @@ import evolution
 
 class Hermes:
     """Encapsulate the process of syncing online friends' information with the
-       Evolution contacts' database. This should be used as follows:
+       Evolution contacts' database.
        
-         * Initialise, passing in a GUI callback.
-         * Call Syncjob.
-         * Retrieve information on changes effected.
-         * Call update_contact to enact manual mapping.
-         
        Copyright (c) Andrew Flegg <andrew@bleb.org> 2010.
        Released under the Artistic Licence."""
 
